@@ -20,8 +20,8 @@
 #'
 #' @examples
 #'
-#' print("this is a method definition. Example is not applicable")
-#' # <SCE_object> |> join_features(features=c("HLA-DRA", "LYZ"))
+#' print("this is a method generics Example is not applicable")
+#' # <object> |> join_features(features=c("HLA-DRA", "LYZ"))
 #'
 #' @docType methods
 #' @rdname join_features
@@ -42,7 +42,7 @@ setGeneric("join_features", function(.data,
 #' @description Combine cells into groups based on shared variables and aggregate feature counts.
 #'
 #' @docType methods
-#' 
+#'
 #' @name aggregate_cells
 #' @rdname aggregate_cells
 #'
@@ -53,11 +53,12 @@ setGeneric("join_features", function(.data,
 #' @param slot The slot to which the function is applied
 #' @param assays The assay to which the function is applied
 #' @param aggregation_function The method of cell-feature value aggregation
+#' @param ... Used for future extendibility
 #'
 #' @return A tibble object
 #'
 #' @examples
-#' 
+#'
 #' print("pbmc_small |> aggregate_cells(c(groups, ident), assays = \"counts\")")
 #'
 #' @export
@@ -66,7 +67,8 @@ setGeneric("aggregate_cells", function(.data,
                                        .sample = NULL,
                                        slot = "data",
                                        assays = NULL,
-                                       aggregation_function = Matrix::rowSums)
+                                       aggregation_function = Matrix::rowSums,
+                                      ...)
   standardGeneric("aggregate_cells"))
 
 
@@ -214,4 +216,4 @@ bind_cols.data.frame <-  function(..., .id = NULL)
 bind_cols.list <-  function(..., .id = NULL)
 {
   dplyr::bind_cols(..., .id = .id)
-}
\ No newline at end of file
+}
